Community
=========

LinchPin has a small, but vibrant community. Come help us while you learn a skill.

.. toctree::
    :maxdepth: 1

    mailing_list
    irc
    source_code
    documentation

.. seealso::

    `User Mailing List <https://www.redhat.com/mailman/listinfo/linchpin>`_
        Subscribe and participate. A great place for Q&A
    `irc.freenode.net <http://irc.freenode.net>`_
        #linchpin IRC chat channel
    `LinchPin on Github <https://github.com/CentOS-PaaS-SIG/linchpin>`_
        Code Contributions and Latest Software
